<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Bir Uygulama Seç</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Kurulu Uygulamalar</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Özel Komut</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Çalıştırılacak komut satırı:</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Uygulama Adı:</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Bu özel kodlar komut satırında kullanılabilir:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Tek dosya adını temsil eder&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Birden fazla dosya adını temsil eder&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Tek dosyanın yolunu temsil eder&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Birden fazla dosyanın yolunu temsil eder&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Komutu çalıştırdıktan sonra uçbirim penceresini açık tut</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Uçbirimde çalıştır</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Seçilen uygulamayı bu dosya türü için öntanımlı olarak ayarla</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Yer İmlerini Düzenle</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Konum</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Öge Ekle</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>Öğeyi &amp;Sil</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Ögeleri yeniden sıralamak için sürükle bırak</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Dosyayı çalıştır</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>Ç&amp;alıştır</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Uçbirim öykünücüsünde çalış&amp;tır</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Hedef:</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>İşleniyor:</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Hazırlanıyor...</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>İlerleme</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Kalan Süre:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Dosya Özellikleri</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Dosya tipi:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Mime Türü:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Dosya boyutu:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Diskteki boyutu:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Son değiştirilme:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Bağlantı hedefi:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Birlikte Aç...</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="267"/>
        <source>Last accessed:</source>
        <translation>Son Erişim:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="285"/>
        <source>Permissions</source>
        <translation>İzinler</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="300"/>
        <source>Ownership</source>
        <translation>Sahiplik</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="324"/>
        <location filename="../../file-props.ui" line="389"/>
        <location filename="../../file-props.ui" line="503"/>
        <source>Group:</source>
        <translation>Grup:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="337"/>
        <location filename="../../file-props.ui" line="372"/>
        <location filename="../../file-props.ui" line="451"/>
        <source>Owner:</source>
        <translation>Sahibi:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="353"/>
        <source>Access Control</source>
        <translation>Erişim Kontrolü</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="406"/>
        <location filename="../../file-props.ui" line="555"/>
        <source>Other:</source>
        <translation>Diğer:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="423"/>
        <source>Make the file executable</source>
        <translation>Dosyayı çalıştırılabilir yap</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="464"/>
        <location filename="../../file-props.ui" line="516"/>
        <location filename="../../file-props.ui" line="568"/>
        <source>Read</source>
        <translation>Okuyabilir</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="477"/>
        <location filename="../../file-props.ui" line="529"/>
        <location filename="../../file-props.ui" line="581"/>
        <source>Write</source>
        <translation>Yaz</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="490"/>
        <location filename="../../file-props.ui" line="542"/>
        <location filename="../../file-props.ui" line="594"/>
        <source>Execute</source>
        <translation>Çalıştır</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="603"/>
        <source>Sticky</source>
        <translation>Yapışkan</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="610"/>
        <source>SetUID</source>
        <translation>SetUID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="617"/>
        <source>SetGID</source>
        <translation>SetUID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="653"/>
        <source>Advanced Mode</source>
        <translation>Gelişmiş Kip</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../../appchoosercombobox.cpp" line="67"/>
        <source>Customize</source>
        <translation>Özelleştir</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../../appchooserdialog.cpp" line="262"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>&quot;%1&quot; dosyalarını açmak için bir uygulama seçin</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../../createnewmenu.cpp" line="30"/>
        <source>Folder</source>
        <translation>Dizin</translation>
    </message>
    <message>
        <location filename="../../createnewmenu.cpp" line="34"/>
        <source>Blank File</source>
        <translation>Boş Dosya</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../../core/dirlistjob.cpp" line="45"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="85"/>
        <source>Loading...</source>
        <translation>Yükleniyor...</translation>
    </message>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="268"/>
        <location filename="../../dirtreemodelitem.cpp" line="312"/>
        <location filename="../../dirtreemodelitem.cpp" line="410"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Alt dizin yok&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../../dirtreeview.cpp" line="211"/>
        <source>Open in New T&amp;ab</source>
        <translation>Yeni Sekme&amp;de Aç</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="215"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Yeni &amp;Pencerede Aç</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="220"/>
        <source>Open in Termina&amp;l</source>
        <translation>&amp;Uçbirimde Aç</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Buraya Kopyala</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Buraya taşı</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Buraya sembolik bağlantı oluştur</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../../editbookmarksdialog.cpp" line="98"/>
        <source>New bookmark</source>
        <translation>Yeni yerimi</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../../execfiledialog.cpp" line="40"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Bu metin dosyası &apos;%1&apos; çalıştırılabilir bir betik gibi görünüyor.
Çalıştırmak ister misiniz?</translation>
    </message>
    <message>
        <location filename="../../execfiledialog.cpp" line="45"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Bu dosya &apos;%1&apos; çalıştırılabilir. Çalıştırmak ister misiniz?</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../../filemenu.cpp" line="82"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="86"/>
        <source>Open With...</source>
        <translation>Birlikte Aç...</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="114"/>
        <source>Other Applications</source>
        <translation>Diğer Uygulamalar</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="120"/>
        <source>Create &amp;New</source>
        <translation>Ye&amp;ni Oluştur</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="139"/>
        <source>&amp;Restore</source>
        <translation>&amp;Geri Yükle</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="145"/>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="149"/>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="153"/>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="157"/>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Çöp Kutusuna Taşı</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="161"/>
        <source>Rename</source>
        <translation>Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="188"/>
        <source>Extract to...</source>
        <translation>Buraya çıkart...</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="193"/>
        <source>Extract Here</source>
        <translation>Buraya çıkart</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="199"/>
        <source>Compress</source>
        <translation>Sıkıştır</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="209"/>
        <source>Properties</source>
        <translation>Özellikler</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="297"/>
        <source>Output</source>
        <translation>Çıktı</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../../fileoperation.cpp" line="227"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="228"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Bazı dosyalar çöğ kutusuna taşınamıyorlar.Çünkü dosya sistemi bu işlemi desteklemiyor. 
Onun yerine silmek ister misiniz?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="270"/>
        <location filename="../../fileoperation.cpp" line="287"/>
        <source>Confirm</source>
        <translation>Doğrula</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="271"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Seçilen dosyaları silmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="288"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Seçilen dosyaları çöp kutusuna taşımak istiyor musunuz?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="41"/>
        <source>Move files</source>
        <translation>Dosyaları Taşı</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="42"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Aşağıdaki dosyalar hedef dizine taşınıyor:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="45"/>
        <source>Copy Files</source>
        <translation>Dosyaları Kopyala</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="46"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Aşağıdaki dosyalar hedef dizine kopyalanıyor:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="49"/>
        <source>Trash Files</source>
        <translation>Dosyaları Çöpe Gönder</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="50"/>
        <source>Moving the following files to trash can:</source>
        <translation>Aşağıdaki dosyalar çöp kutusuna taşınıyor:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="53"/>
        <source>Delete Files</source>
        <translation>Dosyaları Sil</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="54"/>
        <source>Deleting the following files:</source>
        <translation>Aşağıdaki dosyalar siliniyor:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="59"/>
        <source>Create Symlinks</source>
        <translation>Sembolik Bağlantı Oluştur</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="60"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Aşağıdaki dosyalar için sembolik bağlantılar oluşturuluyor:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="63"/>
        <source>Change Attributes</source>
        <translation>Öznitelikleri Değiştir</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="64"/>
        <source>Changing attributes of the following files:</source>
        <translation>Aşağıdaki dosyaların öznitelikleri değişiyor:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="69"/>
        <source>Restore Trashed Files</source>
        <translation>Çöp kutusundaki dosyaları geri yükle</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="70"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Aşağıdaki dosyalar çöp kutusundan geri yüklenebilir:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="134"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../../filepropsdialog.cpp" line="156"/>
        <source>View folder content</source>
        <translation>Dizin içeriğini görebilir</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="157"/>
        <source>View and modify folder content</source>
        <translation>Dizin içeriğini görebilir ve değiştirebilir</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="161"/>
        <source>Read</source>
        <translation>Okuyabilir</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="162"/>
        <source>Read and write</source>
        <translation>Okuyabilir ve Yazabilir</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="164"/>
        <source>Forbidden</source>
        <translation>İzin yok</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="281"/>
        <source>Files of different types</source>
        <translation>Farklı türlerin dosyaları</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="304"/>
        <source>Multiple Files</source>
        <translation>Çoklu Dosyalar</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="380"/>
        <source>Select an icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="382"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="478"/>
        <source>Apply changes</source>
        <translation>Değişiklikleri uygula</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="479"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Bu değişiklikleri tüm dosya ve alt dizinlere uygulamak istiyor musunuz?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Arama yapmak için en az bir dizin eklemelisiniz.</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Bir dizin seç</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>Ye&amp;ni Oluştur</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>&amp;Yapıştır</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>Tümünü &amp;Seç</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>Seçimi Tersine Çevir</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>Sıralama</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>Gizli Dosyaları Göster</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="94"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Dizin Ö&amp;zellikleri</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="137"/>
        <source>Output</source>
        <translation>Çıktı</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="160"/>
        <source>By File Name</source>
        <translation>Dosya Adına Göre</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="161"/>
        <source>By Modification Time</source>
        <translation>Değiştirme Tarihine Göre</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="162"/>
        <source>By File Size</source>
        <translation>Dosya Boyutuna Göre</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="163"/>
        <source>By File Type</source>
        <translation>Dosya Türüne Göre</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="164"/>
        <source>By File Owner</source>
        <translation>Sahibine Göre</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="176"/>
        <source>Ascending</source>
        <translation>Artan</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="181"/>
        <source>Descending</source>
        <translation>Azalan</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="198"/>
        <source>Folder First</source>
        <translation>Önce Dizin</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="208"/>
        <source>Case Sensitive</source>
        <translation>Büyük Küçük Harf Duyarlı</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../../foldermodel.cpp" line="242"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="245"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="248"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="251"/>
        <source>Modified</source>
        <translation>Değiştirildi</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="254"/>
        <source>Owner</source>
        <translation>Sahip</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Yatık</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Bağlan</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../../pathbar.cpp" line="126"/>
        <source>&amp;Edit Path</source>
        <translation>Yolu Düz&amp;enle</translation>
    </message>
    <message>
        <location filename="../../pathbar.cpp" line="129"/>
        <source>&amp;Copy Path</source>
        <translation>Yolu &amp;Kopyala</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../../placesmodel.cpp" line="44"/>
        <source>Places</source>
        <translation>Konumlar</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="52"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="72"/>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="81"/>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="88"/>
        <source>Devices</source>
        <translation>Aygıtlar</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="142"/>
        <source>Bookmarks</source>
        <translation>Yer İmleri</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="231"/>
        <source>Trash</source>
        <translation>Çöp</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../../placesview.cpp" line="356"/>
        <source>Open in New Tab</source>
        <translation>Yeni Sekmede Aç</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="359"/>
        <source>Open in New Window</source>
        <translation>Yeni Pencerede Aç</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="370"/>
        <source>Empty Trash</source>
        <translation>Çöp Kutusunu Boşalt</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="379"/>
        <source>Move Bookmark Up</source>
        <translation>Yer İmini Yukarı Taşı</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="384"/>
        <source>Move Bookmark Down</source>
        <translation>Yer İmini Aşağı Taşı</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="388"/>
        <source>Rename Bookmark</source>
        <translation>Yer imini yeniden adlandır</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="391"/>
        <source>Remove Bookmark</source>
        <translation>Yer imini sil</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="400"/>
        <location filename="../../placesview.cpp" line="417"/>
        <source>Unmount</source>
        <translation>Ayır</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="404"/>
        <source>Mount</source>
        <translation>Bağla</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="410"/>
        <source>Eject</source>
        <translation>Çıkart</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../../renamedialog.cpp" line="50"/>
        <location filename="../../renamedialog.cpp" line="69"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tür: %1
Boyut: %2
Değiştirildi: %3</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="56"/>
        <location filename="../../renamedialog.cpp" line="75"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tür: %1
Değiştirild: %2</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="89"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Üzerine Yaz</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="91"/>
        <source>&amp;Rename</source>
        <translation>&amp;Yeniden Adlandır</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../../sidepane.cpp" line="46"/>
        <source>Places</source>
        <translation>Konumlar</translation>
    </message>
    <message>
        <location filename="../../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Dizin Ağacı</translation>
    </message>
    <message>
        <source>Shows list of common places, devices, and bookmarks in sidebar</source>
        <translation type="vanished">Kenar çubuğunda genel yerlerin, aygıtların ve yer imlerinin bir listesini gösterir</translation>
    </message>
    <message>
        <source>Shows tree of directories in sidebar</source>
        <translation type="vanished">Kenar çubuğunda dizin ağacını gösterir</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Bağla</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Anonim ol&amp;arak bağlan</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>K&amp;ullanıcı olarak bağlan:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>K&amp;ullanıcı adı:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Parola:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Alan:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Parolayı der&amp;hal unut</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="137"/>
        <source>Remember password until you &amp;logout</source>
        <translation>Parolayı &amp;çıkıncaya kadar hatırla</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Her &amp;zaman hatırla</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../utilities.cpp" line="149"/>
        <source>Rename File</source>
        <translation>Dosyayı Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="150"/>
        <source>Please enter a new name:</source>
        <translation>Lütfen yeni bir isim girin:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="143"/>
        <location filename="../../utilities.cpp" line="232"/>
        <location filename="../../mountoperation.cpp" line="186"/>
        <location filename="../../filepropsdialog.cpp" line="503"/>
        <location filename="../../filelauncher.cpp" line="139"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="174"/>
        <source>Create Folder</source>
        <translation>Dizin Oluştur</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="175"/>
        <source>Create File</source>
        <translation>Dosya Oluştur</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="179"/>
        <source>Please enter a new file name:</source>
        <translation>Lütfen yeni bir dosya adı girin:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="180"/>
        <source>New text file</source>
        <translation>Yeni metin dosyası</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="184"/>
        <source>Please enter a new folder name:</source>
        <translation>Lütfen yeni bir dizin adı girin:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="185"/>
        <source>New folder</source>
        <translation>Yeni dizin</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="190"/>
        <source>Enter a name for the new %1:</source>
        <translation>Yeni %1 için bir isim girin:</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="520"/>
        <source>Custom Icon Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Değiştirilecek dosyaları onaylayın</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bu konumda aynı isimli bir dosya zaten var.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Var olan dosyayı değiştirmek istiyor musunuz?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="56"/>
        <source>dest</source>
        <translation>Hedef</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>aşağıdaki dosya ile?</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="76"/>
        <source>src file info</source>
        <translation>kaynak dosya bilgisi</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="89"/>
        <source>dest file info</source>
        <translation>hedef dosya bilgisi</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="102"/>
        <source>src</source>
        <translation>kaynak</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Dosya adı:</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Bu seçeneği tüm var olan dosyalara uygula</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Dosya Ara</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>İsim/Konum</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Dosya Adı Modelleri:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="41"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="48"/>
        <source>Case insensitive</source>
        <translation>Büyük Küçük Harf Duyarlı</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Düzenli ifade kullan</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="65"/>
        <source>Places to Search:</source>
        <translation>Aradığınız Yerler:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="78"/>
        <source>&amp;Add</source>
        <translation>&amp;Ekle</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="90"/>
        <source>&amp;Remove</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="119"/>
        <source>Search in sub directories</source>
        <translation>Alt dizinlerde ara</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="126"/>
        <source>Search for hidden files</source>
        <translation>Gizli dosyalarda ara</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="137"/>
        <source>File Type</source>
        <translation>Dosya Türü</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="143"/>
        <source>Only search for files of following types:</source>
        <translation>Sadece aşağıdaki dosya türleri için arama yap:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="149"/>
        <source>Text files</source>
        <translation>Metin dosyaları</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="156"/>
        <source>Image files</source>
        <translation>Resim dosyaları</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="163"/>
        <source>Audio files</source>
        <translation>Ses dosyası</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="170"/>
        <source>Video files</source>
        <translation>Video dosyaları</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="177"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="184"/>
        <source>Folders</source>
        <translation>Dizinler</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="208"/>
        <source>Content</source>
        <translation>İçerik</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="214"/>
        <source>File contains:</source>
        <translation>Dosya içeriyor:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="223"/>
        <source>Case insensiti&amp;ve</source>
        <translation>Büyük Küçük &amp;Harf Duyarlı</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="230"/>
        <source>&amp;Use regular expression</source>
        <translation>Düzenli ifade k&amp;ullan</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="254"/>
        <source>Properties</source>
        <translation>Özellikler</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="260"/>
        <source>File Size:</source>
        <translation>Dosya Boyutu:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="289"/>
        <source>Larger than:</source>
        <translation>Bundan daha büyük:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="303"/>
        <location filename="../../filesearch.ui" line="333"/>
        <source>Bytes</source>
        <translation>Bit</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="308"/>
        <location filename="../../filesearch.ui" line="338"/>
        <source>KiB</source>
        <translation>KBit</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="313"/>
        <location filename="../../filesearch.ui" line="343"/>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="318"/>
        <location filename="../../filesearch.ui" line="348"/>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="268"/>
        <source>Smaller than:</source>
        <translation>Bundan daha küçük:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="364"/>
        <source>Last Modified Time:</source>
        <translation>Son Değiştirilme Zamanı:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="372"/>
        <source>Earlier than:</source>
        <translation>Bundan önce:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="379"/>
        <source>Later than:</source>
        <translation>Bundan sonra:</translation>
    </message>
</context>
</TS>
